@@ -15,17 +15,19 @@
 #include <memory> // std::allocator
 #include <system_error>
 
-#include <jsoncons/detail/write_number.hpp>
+#include <jsoncons/config/jsoncons_config.hpp>
+#include <jsoncons/allocator_set.hpp>
 #include <jsoncons/json_parser.hpp>
-#include <jsoncons/json_type_traits.hpp>
+#include <jsoncons/json_type.hpp>
 #include <jsoncons/json_visitor.hpp>
-#include <jsoncons/ser_context.hpp>
+#include <jsoncons/semantic_tag.hpp>
+#include <jsoncons/ser_util.hpp>
 #include <jsoncons/sink.hpp>
 #include <jsoncons/staj_event.hpp>
-#include <jsoncons/tag_type.hpp>
 #include <jsoncons/typed_array_view.hpp>
 #include <jsoncons/utility/bigint.hpp>
-#include <jsoncons/value_converter.hpp>
+#include <jsoncons/utility/write_number.hpp>
+#include <jsoncons/utility/conversion.hpp>
 
 namespace jsoncons {
 
@@ -688,6 +690,11 @@ public:
     virtual void next(std::error_code& ec) = 0;
 
     virtual const ser_context& context() const = 0;
+    
+    virtual std::size_t line() const = 0;
+
+    virtual std::size_t column() const = 0;
+    
 };
 
 template <typename CharT>
@@ -750,6 +757,16 @@ public:
         return cursor_->context();
     }
 
+    std::size_t line() const override
+    {
+        return cursor_->line();
+    }
+
+    std::size_t column() const override
+    {
+        return cursor_->column();
+    }
+
     friend
     basic_staj_filter_view<CharT> operator|(basic_staj_filter_view& cursor, 
                                       std::function<bool(const basic_staj_event<CharT>&, const ser_context&)> pred)
@@ -758,6 +775,315 @@ public:
     }
 };
 
+template <typename Json,typename Alloc,typename TempAlloc>
+read_result<Json> to_json_single(const allocator_set<Alloc,TempAlloc>& aset, 
+    basic_staj_cursor<typename Json::char_type>& cursor)
+{
+    using result_type = read_result<Json>;
+
+    std::error_code ec;
+    switch (cursor.current().event_type())
+    {
+        case staj_event_type::string_value:
+        {
+            auto sv = cursor.current().template get<jsoncons::basic_string_view<typename Json::char_type>>(ec);
+            if (ec) return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+            return result_type{jsoncons::make_obj_using_allocator<Json>(aset.get_allocator(),
+                sv.data(), sv.length(), cursor.current().tag())};
+        }
+        case staj_event_type::byte_string_value:
+        {
+            auto j = jsoncons::make_obj_using_allocator<Json>(aset.get_allocator(), 
+                byte_string_arg, cursor.current().template get<byte_string_view>(ec), cursor.current().tag());
+            return !ec ? result_type(std::move(j)) : result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+        }
+        case staj_event_type::null_value:
+        {
+            return result_type(Json{null_arg, semantic_tag::none});
+        }
+        case staj_event_type::bool_value:
+        {
+            auto j = Json{cursor.current().template get<bool>(ec), cursor.current().tag()};
+            return !ec ? result_type(std::move(j)) : result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+        }
+        case staj_event_type::int64_value:
+        {
+            auto j = Json{cursor.current().template get<std::int64_t>(ec), cursor.current().tag()};
+            return !ec ? result_type(std::move(j)) : result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+        }
+        case staj_event_type::uint64_value:
+        {
+            auto j = Json{cursor.current().template get<std::uint64_t>(ec), cursor.current().tag()};
+            return !ec ? result_type(std::move(j)) : result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+        }
+        case staj_event_type::half_value:
+        {
+            auto j = Json{half_arg, cursor.current().template get<std::uint16_t>(ec), cursor.current().tag()};
+            return !ec ? result_type(std::move(j)) : result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+        }
+        case staj_event_type::double_value:
+        {
+            auto j = Json{cursor.current().template get<double>(ec), cursor.current().tag()};
+            return !ec ? result_type(std::move(j)) : result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+        }
+        default:
+            return result_type(jsoncons::unexpect, conv_errc::conversion_failed, cursor.line(), cursor.column());
+    }
+}
+
+template <typename Json, typename Alloc, typename TempAlloc>
+read_result<Json> to_json_container(const allocator_set<Alloc,TempAlloc>& aset, 
+    basic_staj_cursor<typename Json::char_type>& cursor)
+{
+    using result_type = read_result<Json>;
+    using json_ptr_allocator_type = typename std::allocator_traits<TempAlloc>:: template rebind_alloc<Json*>;
+    using char_type = typename Json::char_type;
+    using char_allocator_type = typename std::allocator_traits<TempAlloc>:: template rebind_alloc<char_type>;
+    using key_type = std::basic_string<char_type,std::char_traits<char_type>, char_allocator_type>;
+
+    std::error_code ec;
+
+    auto cont = cursor.current().event_type() == staj_event_type::begin_object ? 
+        jsoncons::make_obj_using_allocator<Json>(aset.get_allocator(), json_object_arg, semantic_tag::none) : 
+        jsoncons::make_obj_using_allocator<Json>(aset.get_allocator(), json_array_arg, semantic_tag::none);
+    std::vector<Json*,json_ptr_allocator_type> stack(aset.get_temp_allocator());
+    stack.push_back(std::addressof(cont));
+    key_type key(aset.get_temp_allocator());
+    if (cursor.current().event_type() == staj_event_type::begin_object)
+    {
+        goto begin_object;
+    }
+    goto begin_array;
+    
+begin_object:    
+    cursor.next(ec);
+    if (JSONCONS_UNLIKELY(ec))
+    {
+        return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+    }
+    while (!cursor.done() && !stack.empty())
+    {
+        switch (cursor.current().event_type())
+        {
+            case staj_event_type::begin_object:
+            {
+                auto result = stack.back()->try_emplace(key, json_object_arg);
+                stack.push_back(std::addressof(result.first->value()));
+                goto begin_object;
+            }
+            case staj_event_type::begin_array:
+            {
+                auto result = stack.back()->try_emplace(key, json_array_arg);
+                stack.push_back(std::addressof(result.first->value()));
+                goto begin_array;
+            }
+            case staj_event_type::key:
+            {
+                auto sv = cursor.current().template get<basic_string_view<char_type>>(ec);
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                key = key_type(sv.data(), sv.length(), aset.get_temp_allocator());
+                break;
+            }
+            case staj_event_type::string_value:
+                stack.back()->try_emplace(key, cursor.current().template get<jsoncons::basic_string_view<char_type>>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::byte_string_value:
+                stack.back()->try_emplace(key, byte_string_arg, cursor.current().template get<byte_string_view>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::null_value:
+                stack.back()->try_emplace(key, null_arg);
+                break;
+            case staj_event_type::bool_value:
+                stack.back()->try_emplace(key, cursor.current().template get<bool>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::int64_value:
+                stack.back()->try_emplace(key, cursor.current().template get<std::int64_t>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::uint64_value:
+                stack.back()->try_emplace(key, cursor.current().template get<std::uint64_t>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::half_value:
+                stack.back()->try_emplace(key, half_arg, cursor.current().template get<std::uint16_t>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::double_value:
+                stack.back()->try_emplace(key, cursor.current().template get<double>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::end_object:
+                stack.pop_back();
+                if (stack.empty())
+                {
+                    return result_type(std::move(cont));
+                }
+                if (stack.back()->type() == json_type::object_value)
+                {
+                    goto begin_object;
+                }
+                goto begin_array;
+                break;
+            default:
+                return result_type(jsoncons::unexpect, conv_errc::conversion_failed, cursor.line(), cursor.column());
+        }
+        cursor.next(ec);
+        if (JSONCONS_UNLIKELY(ec))
+        {
+            return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+        }
+    }
+    return result_type(std::move(cont));
+
+begin_array:    
+    cursor.next(ec);
+    if (JSONCONS_UNLIKELY(ec))
+    {
+        return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+    }
+    while (!cursor.done() && !stack.empty())
+    {
+        switch (cursor.current().event_type())
+        {
+            case staj_event_type::begin_object:
+            {
+                auto& result = stack.back()->emplace_back(json_object_arg);
+                stack.push_back(std::addressof(result));
+                goto begin_object;
+            }
+            case staj_event_type::begin_array:
+            {
+                auto& result = stack.back()->emplace_back(json_array_arg);
+                stack.push_back(std::addressof(result));
+                goto begin_array;
+            }
+            case staj_event_type::string_value:
+                stack.back()->emplace_back(cursor.current().template get<jsoncons::basic_string_view<char_type>>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::byte_string_value:
+                stack.back()->emplace_back(byte_string_arg, cursor.current().template get<byte_string_view>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::null_value:
+                stack.back()->emplace_back(null_arg);
+                break;
+            case staj_event_type::bool_value:
+                stack.back()->emplace_back(cursor.current().template get<bool>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::int64_value:
+                stack.back()->emplace_back(cursor.current().template get<std::int64_t>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::uint64_value:
+                stack.back()->emplace_back(cursor.current().template get<std::uint64_t>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::half_value:
+                stack.back()->emplace_back(half_arg, cursor.current().template get<std::uint16_t>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::double_value:
+                stack.back()->emplace_back(cursor.current().template get<double>(ec), cursor.current().tag());
+                if (JSONCONS_UNLIKELY(ec))
+                {
+                    return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+                }
+                break;
+            case staj_event_type::end_array:
+                stack.pop_back();
+                if (stack.empty())
+                {
+                    return cont;
+                }
+                if (stack.back()->type() == json_type::object_value)
+                {
+                    goto begin_object;
+                }
+                goto begin_array;
+                break;
+            default:
+                return result_type(jsoncons::unexpect, conv_errc::conversion_failed, cursor.line(), cursor.column());
+        }
+        cursor.next(ec);
+        if (JSONCONS_UNLIKELY(ec))
+        {
+            return result_type(jsoncons::unexpect, ec, cursor.line(), cursor.column());
+        }
+    }
+    
+    JSONCONS_UNREACHABLE();
+}
+
+template <typename Json, typename Alloc, typename TempAlloc>
+read_result<Json> try_to_json(const allocator_set<Alloc,TempAlloc>& aset, 
+    basic_staj_cursor<typename Json::char_type>& cursor)
+{
+    using result_type = read_result<Json>;
+
+    if (JSONCONS_UNLIKELY(is_end_container(cursor.current().event_type())))
+    {
+        return result_type(jsoncons::unexpect, conv_errc::conversion_failed, cursor.line(), cursor.column());
+    }
+    if (!is_begin_container(cursor.current().event_type()))
+    {
+        return to_json_single<Json>(aset, cursor);
+    }
+    return to_json_container<Json>(aset, cursor);
+}
+
+template <typename Json>
+read_result<Json> try_to_json(basic_staj_cursor<typename Json::char_type>& cursor)
+{
+    return try_to_json<Json>(allocator_set<typename Json::allocator_type, std::allocator<char>>(), cursor);
+}
+
 using staj_event = basic_staj_event<char>;
 using wstaj_event = basic_staj_event<wchar_t>;
 
