@@ -8,22 +8,22 @@
 #define JSONCONS_EXT_JSONPOINTER_JSONPOINTER_HPP
 
 #include <cstddef>
-#include <iostream>
 #include <memory>
+#include <ostream>
 #include <string>
 #include <system_error> // system_error
 #include <type_traits> // std::enable_if, std::true_type
 #include <utility> // std::move
 #include <vector>
 
-#include <jsoncons/detail/write_number.hpp>
+#include <jsoncons/utility/write_number.hpp>
 #include <jsoncons/json_type.hpp>
-#include <jsoncons/tag_type.hpp>
-#include <jsoncons/utility/extension_traits.hpp>
+#include <jsoncons/utility/more_type_traits.hpp>
 
 #include <jsoncons_ext/jsonpointer/jsonpointer_error.hpp>
 
-namespace jsoncons { namespace jsonpointer {
+namespace jsoncons { 
+namespace jsonpointer {
 
     namespace detail {
 
@@ -122,7 +122,7 @@ namespace jsoncons { namespace jsonpointer {
         {
             std::error_code ec;
             auto jp = parse(s, ec);
-            if (ec)
+            if (JSONCONS_UNLIKELY(ec))
             {
                 JSONCONS_THROW(jsonpointer_error(ec));
             }
@@ -242,11 +242,11 @@ namespace jsoncons { namespace jsonpointer {
         }
 
         template <typename IntegerType>
-        typename std::enable_if<extension_traits::is_integer<IntegerType>::value, basic_json_pointer&>::type
+        typename std::enable_if<ext_traits::is_integer<IntegerType>::value, basic_json_pointer&>::type
         append(IntegerType val)
         {
             string_type s;
-            jsoncons::detail::from_integer(val, s);
+            jsoncons::utility::from_integer(val, s);
             tokens_.push_back(s);
 
             return *this;
@@ -259,11 +259,11 @@ namespace jsoncons { namespace jsonpointer {
         }
 
         template <typename IntegerType>
-        typename std::enable_if<extension_traits::is_integer<IntegerType>::value, basic_json_pointer&>::type
+        typename std::enable_if<ext_traits::is_integer<IntegerType>::value, basic_json_pointer&>::type
         operator/=(IntegerType val)
         {
             string_type s;
-            jsoncons::detail::from_integer(val, s);
+            jsoncons::utility::from_integer(val, s);
             tokens_.push_back(s);
 
             return *this;
@@ -361,7 +361,7 @@ namespace jsoncons { namespace jsonpointer {
         }
 
         friend std::basic_ostream<CharT>&
-        operator<<( std::basic_ostream<CharT>& os, const basic_json_pointer<CharT>& p )
+        operator<<(std::basic_ostream<CharT>& os, const basic_json_pointer<CharT>& p )
         {
             os << p.to_string();
             return os;
@@ -369,7 +369,7 @@ namespace jsoncons { namespace jsonpointer {
     };
 
     template <typename CharT,typename IntegerType>
-    typename std::enable_if<extension_traits::is_integer<IntegerType>::value, basic_json_pointer<CharT>>::type
+    typename std::enable_if<ext_traits::is_integer<IntegerType>::value, basic_json_pointer<CharT>>::type
     operator/(const basic_json_pointer<CharT>& lhs, IntegerType rhs)
     {
         basic_json_pointer<CharT> p(lhs);
@@ -405,7 +405,7 @@ namespace jsoncons { namespace jsonpointer {
                 return current;
             }
             std::size_t index{0};
-            auto result = jsoncons::detail::decimal_to_integer(buffer.data(), buffer.length(), index);
+            auto result = jsoncons::utility::dec_to_integer(buffer.data(), buffer.length(), index);
             if (!result)
             {
                 ec = jsonpointer_errc::invalid_index;
@@ -446,7 +446,7 @@ namespace jsoncons { namespace jsonpointer {
                 return current;
             }
             std::size_t index{0};
-            auto result = jsoncons::detail::decimal_to_integer(buffer.data(), buffer.length(), index);
+            auto result = jsoncons::utility::dec_to_integer(buffer.data(), buffer.length(), index);
             if (!result)
             {
                 ec = jsonpointer_errc::invalid_index;
@@ -508,7 +508,7 @@ namespace jsoncons { namespace jsonpointer {
         while (it != end)
         {
             current = jsoncons::jsonpointer::detail::resolve(current, *it, create_if_missing, ec);
-            if (ec)
+            if (JSONCONS_UNLIKELY(ec))
                 return *current;
             ++it;
         }
@@ -523,7 +523,7 @@ namespace jsoncons { namespace jsonpointer {
         std::error_code& ec)
     {
         auto jsonptr = basic_json_pointer<typename Json::char_type>::parse(location_str, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             return root;
         }
@@ -546,7 +546,7 @@ namespace jsoncons { namespace jsonpointer {
         while (it != end)
         {
             current = jsoncons::jsonpointer::detail::resolve(current, *it, ec);
-            if (ec)
+            if (JSONCONS_UNLIKELY(ec))
                 return *current;
             ++it;
         }
@@ -560,7 +560,7 @@ namespace jsoncons { namespace jsonpointer {
         std::error_code& ec)
     {
         auto jsonptr = basic_json_pointer<typename Json::char_type>::parse(location_str, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             return root;
         }
@@ -591,7 +591,7 @@ namespace jsoncons { namespace jsonpointer {
     {
         std::error_code ec;
         Json& j = get(root, location, create_if_missing, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             JSONCONS_THROW(jsonpointer_error(ec));
         }
@@ -606,7 +606,7 @@ namespace jsoncons { namespace jsonpointer {
     {
         std::error_code ec;
         Json& result = get(root, location_str, create_if_missing, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             JSONCONS_THROW(jsonpointer_error(ec));
         }
@@ -618,7 +618,7 @@ namespace jsoncons { namespace jsonpointer {
     {
         std::error_code ec;
         const Json& j = get(root, location, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             JSONCONS_THROW(jsonpointer_error(ec));
         }
@@ -631,7 +631,7 @@ namespace jsoncons { namespace jsonpointer {
     {
         std::error_code ec;
         const Json& j = get(root, location_str, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             JSONCONS_THROW(jsonpointer_error(ec));
         }
@@ -664,6 +664,12 @@ namespace jsoncons { namespace jsonpointer {
              bool create_if_missing,
              std::error_code& ec)
     {
+        if (location.empty())
+        {
+            root = std::forward<T>(value);
+            return;
+        }
+
         Json* current = std::addressof(root);
 
         std::basic_string<typename Json::char_type> buffer;
@@ -676,7 +682,7 @@ namespace jsoncons { namespace jsonpointer {
             if (it != end)
             {
                 current = jsoncons::jsonpointer::detail::resolve(current, buffer, create_if_missing, ec);
-                if (ec)
+                if (JSONCONS_UNLIKELY(ec))
                     return;
             }
         }
@@ -690,7 +696,7 @@ namespace jsoncons { namespace jsonpointer {
             else
             {
                 std::size_t index{0};
-                auto result = jsoncons::detail::decimal_to_integer(buffer.data(), buffer.length(), index);
+                auto result = jsoncons::utility::dec_to_integer(buffer.data(), buffer.length(), index);
                 if (!result)
                 {
                     ec = jsonpointer_errc::invalid_index;
@@ -735,7 +741,7 @@ namespace jsoncons { namespace jsonpointer {
              std::error_code& ec)
     {
         auto jsonptr = basic_json_pointer<typename Json::char_type>::parse(location_str, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             return;
         }
@@ -769,7 +775,7 @@ namespace jsoncons { namespace jsonpointer {
     {
         std::error_code ec;
         add(root, location, std::forward<T>(value), create_if_missing, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             JSONCONS_THROW(jsonpointer_error(ec));
         }
@@ -784,7 +790,7 @@ namespace jsoncons { namespace jsonpointer {
     {
         std::error_code ec;
         add(root, location_str, std::forward<T>(value), create_if_missing, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             JSONCONS_THROW(jsonpointer_error(ec));
         }
@@ -799,6 +805,11 @@ namespace jsoncons { namespace jsonpointer {
                        bool create_if_missing,
                        std::error_code& ec)
     {
+        if (location.empty())
+        {
+            root = std::forward<T>(value);
+            return;
+        }
         Json* current = std::addressof(root);
 
         std::basic_string<typename Json::char_type> buffer;
@@ -812,7 +823,7 @@ namespace jsoncons { namespace jsonpointer {
             if (it != end)
             {
                 current = jsoncons::jsonpointer::detail::resolve(current, buffer, create_if_missing, ec);
-                if (ec)
+                if (JSONCONS_UNLIKELY(ec))
                     return;
             }
         }
@@ -826,7 +837,7 @@ namespace jsoncons { namespace jsonpointer {
             else
             {
                 std::size_t index{0};
-                auto result = jsoncons::detail::decimal_to_integer(buffer.data(), buffer.length(), index);
+                auto result = jsoncons::utility::dec_to_integer(buffer.data(), buffer.length(), index);
                 if (!result)
                 {
                     ec = jsonpointer_errc::invalid_index;
@@ -878,7 +889,7 @@ namespace jsoncons { namespace jsonpointer {
                        std::error_code& ec)
     {
         auto jsonptr = basic_json_pointer<typename Json::char_type>::parse(location_str, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             return;
         }
@@ -904,7 +915,7 @@ namespace jsoncons { namespace jsonpointer {
     {
         std::error_code ec;
         add_if_absent(root, location_str, std::forward<T>(value), create_if_missing, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             JSONCONS_THROW(jsonpointer_error(ec));
         }
@@ -927,7 +938,7 @@ namespace jsoncons { namespace jsonpointer {
     {
         std::error_code ec;
         add_if_absent(root, location, std::forward<T>(value), create_if_missing, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             JSONCONS_THROW(jsonpointer_error(ec));
         }
@@ -938,6 +949,12 @@ namespace jsoncons { namespace jsonpointer {
     template <typename Json>
     void remove(Json& root, const basic_json_pointer<typename Json::char_type>& location, std::error_code& ec)
     {
+        if (location.empty())
+        {
+            ec = jsonpointer_errc::cannot_remove_root;
+            return;
+        }
+
         Json* current = std::addressof(root);
 
         std::basic_string<typename Json::char_type> buffer;
@@ -951,7 +968,7 @@ namespace jsoncons { namespace jsonpointer {
             if (it != end)
             {
                 current = jsoncons::jsonpointer::detail::resolve(current, buffer, false, ec);
-                if (ec)
+                if (JSONCONS_UNLIKELY(ec))
                     return;
             }
         }
@@ -965,7 +982,7 @@ namespace jsoncons { namespace jsonpointer {
             else
             {
                 std::size_t index{0};
-                auto result = jsoncons::detail::decimal_to_integer(buffer.data(), buffer.length(), index);
+                auto result = jsoncons::utility::dec_to_integer(buffer.data(), buffer.length(), index);
                 if (!result)
                 {
                     ec = jsonpointer_errc::invalid_index;
@@ -1003,7 +1020,7 @@ namespace jsoncons { namespace jsonpointer {
     remove(Json& root, const StringSource& location_str, std::error_code& ec)
     {
         auto jsonptr = basic_json_pointer<typename Json::char_type>::parse(location_str, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             return;
         }
@@ -1016,7 +1033,7 @@ namespace jsoncons { namespace jsonpointer {
     {
         std::error_code ec;
         remove(root, location_str, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             JSONCONS_THROW(jsonpointer_error(ec));
         }
@@ -1027,7 +1044,7 @@ namespace jsoncons { namespace jsonpointer {
     {
         std::error_code ec;
         remove(root, location, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             JSONCONS_THROW(jsonpointer_error(ec));
         }
@@ -1042,6 +1059,11 @@ namespace jsoncons { namespace jsonpointer {
                  bool create_if_missing,
                  std::error_code& ec)
     {
+        if (location.empty())
+        {
+            root = std::forward<T>(value);
+            return;
+        }
         Json* current = std::addressof(root);
 
         std::basic_string<typename Json::char_type> buffer;
@@ -1055,7 +1077,7 @@ namespace jsoncons { namespace jsonpointer {
             if (it != end)
             {
                 current = jsoncons::jsonpointer::detail::resolve(current, buffer, create_if_missing, ec);
-                if (ec)
+                if (JSONCONS_UNLIKELY(ec))
                     return;
             }
         }
@@ -1069,7 +1091,7 @@ namespace jsoncons { namespace jsonpointer {
             else
             {
                 std::size_t index{};
-                auto result = jsoncons::detail::decimal_to_integer(buffer.data(), buffer.length(), index);
+                auto result = jsoncons::utility::dec_to_integer(buffer.data(), buffer.length(), index);
                 if (!result)
                 {
                     ec = jsonpointer_errc::invalid_index;
@@ -1119,7 +1141,7 @@ namespace jsoncons { namespace jsonpointer {
                  std::error_code& ec)
     {
         auto jsonptr = basic_json_pointer<typename Json::char_type>::parse(location_str, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             return;
         }
@@ -1145,7 +1167,7 @@ namespace jsoncons { namespace jsonpointer {
     {
         std::error_code ec;
         replace(root, location_str, std::forward<T>(value), create_if_missing, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             JSONCONS_THROW(jsonpointer_error(ec));
         }
@@ -1168,7 +1190,7 @@ namespace jsoncons { namespace jsonpointer {
     {
         std::error_code ec;
         replace(root, location, std::forward<T>(value), create_if_missing, ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             JSONCONS_THROW(jsonpointer_error(ec));
         }
@@ -1224,7 +1246,7 @@ namespace jsoncons { namespace jsonpointer {
                     {
                         string_type key(parent_key);
                         key.push_back('/');
-                        jsoncons::detail::from_integer(i,key);
+                        jsoncons::utility::from_integer(i,key);
                         flatten_(key, parent_value.at(i), result);
                     }
                 }
@@ -1290,7 +1312,7 @@ namespace jsoncons { namespace jsonpointer {
         for (const auto& item : value.object_range())
         {
             std::size_t n;
-            auto r = jsoncons::detail::decimal_to_integer(item.key().data(),item.key().size(), n);
+            auto r = jsoncons::utility::dec_to_integer(item.key().data(),item.key().size(), n);
             if (!r || (index++ != n))
             {
                 safe = false;
@@ -1344,8 +1366,8 @@ namespace jsoncons { namespace jsonpointer {
             {
                 auto s = *it;
                 std::size_t n{0};
-                auto r = jsoncons::detail::decimal_to_integer(s.data(), s.size(), n);
-                if (r.ec == jsoncons::detail::to_integer_errc() && (index++ == n))
+                auto r = jsoncons::utility::dec_to_integer(s.data(), s.size(), n);
+                if (r.ec == std::errc() && (index++ == n))
                 {
                     if (!part->is_array())
                     {
