@@ -18,7 +18,7 @@ TEST_CASE("test_initializer_list_of_integers")
 {
     json doc(json_array_arg, {0,1,2,3});
     CHECK(doc.is_array());
-    CHECK(doc.size() == 4);
+    CHECK(4 == doc.size());
     for (std::size_t i = 0; i < doc.size(); ++i)
     {
         CHECK(i == doc[i].as<std::size_t>());
@@ -31,7 +31,7 @@ TEST_CASE("test_assignment_to_initializer_list")
 
     doc = json(json_array_arg, {0,1,2,3});
     CHECK(doc.is_array());
-    CHECK(doc.size() == 4);
+    CHECK(4 == doc.size());
     for (std::size_t i = 0; i < doc.size(); ++i)
     {
         CHECK(i == doc[i].as<std::size_t>());
@@ -51,15 +51,15 @@ TEST_CASE("test_assignment_to_initializer_list2")
                                       json(json_array_arg, {2}),
                                       json(json_array_arg, {4,3})});
 
-    CHECK(val["data"]["item"][0][0] == json(2));
-    CHECK(val["data"]["item"][1][0] == json(4));
-    CHECK(val["data"]["item"][2][0] == json(4));
-    CHECK(val["data"]["item"][3][0] == json(4));
-    CHECK(val["data"]["item"][4][0] == json(2));
-    CHECK(val["data"]["item"][5][0] == json(4));
-    CHECK(val["data"]["item"][6][0] == json(2));
-    CHECK(val["data"]["item"][7][0] == json(4));
-    CHECK(val["data"]["item"][7][1] == json(3));
+    CHECK(json(2) == val["data"]["item"][0][0]);
+    CHECK(json(4) == val["data"]["item"][1][0]);
+    CHECK(json(4) == val["data"]["item"][2][0]);
+    CHECK(json(4) == val["data"]["item"][3][0]);
+    CHECK(json(2) == val["data"]["item"][4][0]);
+    CHECK(json(4) == val["data"]["item"][5][0]);
+    CHECK(json(2) == val["data"]["item"][6][0]);
+    CHECK(json(4) == val["data"]["item"][7][0]);
+    CHECK(json(3) == val["data"]["item"][7][1]);
 }
 
 TEST_CASE("test_assignment_to_initializer_list3")
@@ -89,7 +89,7 @@ TEST_CASE("test_assign_initializer_list_of_object")
 
     doc = json(json_array_arg, {transaction});
     CHECK(doc.is_array());
-    CHECK(doc.size() == 1);
+    CHECK(1 == doc.size());
     CHECK(doc[0] == transaction);
 }
 
@@ -105,7 +105,7 @@ TEST_CASE("test_initializer_list_of_objects")
 
     json doc(json_array_arg, {book1, book2});
     CHECK(doc.is_array());
-    CHECK(doc.size() == 2);
+    CHECK(2 == doc.size());
 
     CHECK(book1 == doc[0]);
     CHECK(book2 == doc[1]);
@@ -123,7 +123,7 @@ TEST_CASE("test_array_constructor")
 TEST_CASE("test_make_array")
 {
     json doc(json_array_arg);
-    CHECK(doc.size() == 0);
+    CHECK(0 == doc.size());
     doc.resize(10,10.0);
     CHECK(doc.is_array());
     CHECK(doc.size() == 10);
@@ -140,7 +140,7 @@ TEST_CASE("test_add_element_to_array")
     doc.push_back("Vancouver");
     doc.insert(doc.array_range().begin(),"Montreal");
 
-    CHECK(doc.size() == 3);
+    CHECK(3 == doc.size());
 
     CHECK(doc[0].as<std::string>() == std::string("Montreal"));
     CHECK(doc[1].as<std::string>() == std::string("Toronto"));
@@ -156,7 +156,7 @@ TEST_CASE("test_emplace_element_to_array")
     a.emplace_back("Vancouver");
     a.emplace(a.array_range().begin(),"Montreal");
 
-    CHECK(a.size() == 3);
+    CHECK(3 == a.size());
 
     CHECK(a[0].as<std::string>() == std::string("Montreal"));
     CHECK(a[1].as<std::string>() == std::string("Toronto"));
@@ -172,7 +172,7 @@ TEST_CASE("test_array_add_pos")
     arr.push_back("Vancouver");
     arr.insert(arr.array_range().begin(),"Montreal");
 
-    CHECK(arr.size() == 3);
+    CHECK(3 == arr.size());
 
     CHECK(arr[0].as<std::string>() == std::string("Montreal"));
     CHECK(arr[1].as<std::string>() == std::string("Toronto"));
@@ -188,11 +188,11 @@ TEST_CASE("test_array_erase_range")
     arr.push_back("Vancouver");
     arr.insert(arr.array_range().begin(),"Montreal");
 
-    CHECK(arr.size() == 3);
+    CHECK(3 == arr.size());
 
     arr.erase(arr.array_range().begin()+1,arr.array_range().end());
 
-    CHECK(arr.size() == 1);
+    CHECK(1 == arr.size());
     CHECK(arr[0].as<std::string>() == std::string("Montreal"));
 }
 
@@ -203,24 +203,24 @@ TEST_CASE("test_reserve_array_capacity")
     CHECK(cities.is_array());
     cities.reserve(10);  // storage is allocated
     CHECK(cities.capacity() == 10);
-    CHECK(cities.size() == 0);
+    CHECK(0 == cities.size());
 
     cities.push_back("Toronto");
     CHECK(cities.is_array());
     CHECK(cities.is_array());
     CHECK(cities.capacity() == 10);
-    CHECK(cities.size() == 1);
+    CHECK(1 == cities.size());
     cities.push_back("Vancouver");
     cities.insert(cities.array_range().begin(),"Montreal");
     CHECK(cities.capacity() == 10);
-    CHECK(cities.size() == 3);
+    CHECK(3 == cities.size());
 }
 
 TEST_CASE("test make_array()")
 {
     json doc = json::make_array();
     CHECK(doc.is_array());
-    CHECK(doc.size() == 0);
+    CHECK(0 == doc.size());
     doc.emplace_back("Toronto");
     doc.emplace_back("Vancouver");
     doc.emplace(doc.array_range().begin(),"Montreal");
@@ -233,22 +233,22 @@ TEST_CASE("test_one_dim_array")
 {
     basic_json<char,sorted_policy,std::allocator<char>> a = basic_json<char,sorted_policy,std::allocator<char>>::make_array<1>(10,0);
     CHECK(a.size() == 10);
-    CHECK(a[0].as<int64_t>() == 0);
+    CHECK(0 == a[0].as<int64_t>());
     a[1] = 1;
     a[2] = 2;
-    CHECK(a[1].as<int64_t>() == 1);
-    CHECK(a[2].as<int64_t>() == 2);
-    CHECK(a[9].as<int64_t>() == 0);
+    CHECK(1 == a[1].as<int64_t>());
+    CHECK(2 == a[2].as<int64_t>());
+    CHECK(0 == a[9].as<int64_t>());
 
-    CHECK(a[1].as<long long>() == 1);
-    CHECK(a[2].as<long long>() == 2);
-    CHECK(a[9].as<long long>() == 0);
+    CHECK(1 == a[1].as<long long>());
+    CHECK(2 == a[2].as<long long>());
+    CHECK(0 == a[9].as<long long>());
 }
 
 TEST_CASE("test_two_dim_array")
 {
     json a = json::make_array<2>(3,4,0);
-    CHECK(a.size() == 3);
+    CHECK(3 == a.size());
     a[0][0] = "Tenor";
     a[0][1] = "ATM vol";
     a[0][2] = "25-d-MS";
@@ -272,17 +272,17 @@ TEST_CASE("test_two_dim_array")
 TEST_CASE("test_three_dim_array")
 {
     json a = json::make_array<3>(4,3,2,0);
-    CHECK(a.size() == 4);
+    CHECK(4 == a.size());
     a[0][2][0] = 2;
     a[0][2][1] = 3;
 
-    CHECK(a[0][2][0].as<int64_t>() == 2);
-    CHECK(a[0][2][1].as<int64_t>() == 3);
-    CHECK(a[3][2][1].as<int64_t>() == 0);
+    CHECK(2 == a[0][2][0].as<int64_t>());
+    CHECK(3 == a[0][2][1].as<int64_t>());
+    CHECK(0 == a[3][2][1].as<int64_t>());
 
-    CHECK(a[0][2][0].as<long long>() == 2);
-    CHECK(a[0][2][1].as<long long>() == 3);
-    CHECK(a[3][2][1].as<long long>() == 0);
+    CHECK(2 == a[0][2][0].as<long long>());
+    CHECK(3 == a[0][2][1].as<long long>());
+    CHECK(0 == a[3][2][1].as<long long>());
 }
 
 TEST_CASE("test_array_assign_vector")
@@ -295,7 +295,7 @@ TEST_CASE("test_array_assign_vector")
     json val;
     val = vec;
 
-    CHECK(val.size() == 3);
+    CHECK(3 == val.size());
     CHECK(val[0].as<std::string>() ==std::string("Toronto"));
     CHECK(val[1].as<std::string>() ==std::string("Vancouver"));
     CHECK(val[2].as<std::string>() ==std::string("Montreal"));
@@ -312,7 +312,7 @@ TEST_CASE("test_array_assign_vector_of_bool")
     json val;
     val = vec;
 
-    CHECK(val.size() == 3);
+    CHECK(3 == val.size());
     CHECK(val[0].as<bool>() == true);
     CHECK(val[1].as<bool>() == false);
     CHECK(val[2].as<bool>() == true);
@@ -336,7 +336,7 @@ TEST_CASE("test_array_from_container")
     vec.push_back(30);
 
     json val1 = vec;
-    REQUIRE(vec.size() == 3);
+    REQUIRE(3 == vec.size());
     CHECK(vec[0] == 10);
     CHECK(vec[1] == 20);
     CHECK(vec[2] == 30);
@@ -347,7 +347,7 @@ TEST_CASE("test_array_from_container")
     list.push_back(30.5);
 
     json val2 = list;
-    REQUIRE(val2.size() == 3);
+    REQUIRE(3 == val2.size());
     CHECK(val2[0].as<double>() == Approx(10.5).epsilon(0.000001));
     CHECK(val2[1].as<double>() == Approx(20.5).epsilon(0.000001));
     CHECK(val2[2].as<double>() == Approx(30.5).epsilon(0.000001));
@@ -359,7 +359,7 @@ TEST_CASE("test_array_as_vector_of_double")
     json val = json::parse(s);
 
     std::vector<double> v = val.as<std::vector<double>>(); 
-    CHECK(v.size() == 4);
+    CHECK(4 == v.size());
     CHECK(v[0] == Approx(0.0).epsilon(0.0000000001));
     CHECK(v[1] == Approx(1.1).epsilon(0.0000000001));
     CHECK(v[2] == Approx(2.0).epsilon(0.0000000001));
@@ -372,7 +372,7 @@ TEST_CASE("test_array_as_vector_of_bool")
     json val = json::parse(s);
 
     std::vector<bool> v = val.as<std::vector<bool>>(); 
-    CHECK(v.size() == 3);
+    CHECK(3 == v.size());
     CHECK(v[0] == true);
     CHECK(v[1] == false);
     CHECK(v[2] == true);
@@ -384,7 +384,7 @@ TEST_CASE("test_array_as_vector_of_string")
     json val = json::parse(s);
 
     std::vector<std::string> v = val.as<std::vector<std::string>>(); 
-    CHECK(v.size() == 2);
+    CHECK(2 == v.size());
     CHECK(v[0] == "Hello");
     CHECK(v[1] == "World");
 }
@@ -395,7 +395,7 @@ TEST_CASE("test_array_as_vector_of_char")
     json val = json::parse(s);
 
     std::vector<char> v = val.as<std::vector<char>>(); 
-    CHECK(v.size() == 2);
+    CHECK(2 == v.size());
     CHECK(v[0] == 20);
     CHECK(v[1] == 30);
 }
@@ -406,46 +406,46 @@ TEST_CASE("test_array_as_vector_of_int")
     json val = json::parse(s);
 
     std::vector<int> v = val.as<std::vector<int>>(); 
-    CHECK(v.size() == 4);
-    CHECK(v[0]==0);
-    CHECK(v[1]==1);
-    CHECK(v[2]==2);
-    CHECK(v[3]==3);
+    CHECK(4 == v.size());
+    CHECK(0 == v[0]);
+    CHECK(1 == v[1]);
+    CHECK(2 == v[2]);
+    CHECK(3 == v[3]);
 
     std::vector<unsigned int> v1 = val.as<std::vector<unsigned int>>(); 
-    CHECK(v1.size() == 4);
-    CHECK(v1[0]==0);
-    CHECK(v1[1]==1);
-    CHECK(v1[2]==2);
-    CHECK(v1[3]==3);
+    CHECK(4 == v1.size());
+    CHECK(0 == v1[0]);
+    CHECK(1 == v1[1]);
+    CHECK(2 == v1[2]);
+    CHECK(3 == v1[3]);
 
     std::vector<long> v2 = val.as<std::vector<long>>(); 
-    CHECK(v2.size() == 4);
-    CHECK(v2[0]==0);
-    CHECK(v2[1]==1);
-    CHECK(v2[2]==2);
-    CHECK(v2[3]==3);
+    CHECK(4 == v2.size());
+    CHECK(0 == v2[0]);
+    CHECK(1 == v2[1]);
+    CHECK(2 == v2[2]);
+    CHECK(3 == v2[3]);
 
     std::vector<unsigned long> v3 = val.as<std::vector<unsigned long>>(); 
-    CHECK(v3.size() == 4);
-    CHECK(v3[0]==0);
-    CHECK(v3[1]==1);
-    CHECK(v3[2]==2);
-    CHECK(v3[3]==3);
+    CHECK(4 == v3.size());
+    CHECK(0 == v3[0]);
+    CHECK(1 == v3[1]);
+    CHECK(2 == v3[2]);
+    CHECK(3 == v3[3]);
 
     std::vector<long long> v4 = val.as<std::vector<long long>>(); 
-    CHECK(v4.size() == 4);
-    CHECK(v4[0]==0);
-    CHECK(v4[1]==1);
-    CHECK(v4[2]==2);
-    CHECK(v4[3]==3);
+    CHECK(4 == v4.size());
+    CHECK(0 == v4[0]);
+    CHECK(1 == v4[1]);
+    CHECK(2 == v4[2]);
+    CHECK(3 == v4[3]);
 
     std::vector<unsigned long long> v5 = val.as<std::vector<unsigned long long>>(); 
-    CHECK(v5.size() == 4);
-    CHECK(v5[0]==0);
-    CHECK(v5[1]==1);
-    CHECK(v5[2]==2);
-    CHECK(v5[3]==3);
+    CHECK(4 == v5.size());
+    CHECK(0 == v5[0]);
+    CHECK(1 == v5[1]);
+    CHECK(2 == v5[2]);
+    CHECK(3 == v5[3]);
 }
 
 TEST_CASE("test_array_as_vector_of_int_on_proxy")
@@ -455,11 +455,11 @@ TEST_CASE("test_array_as_vector_of_int_on_proxy")
     json root;
     root["val"] = val;
     std::vector<int> v = root["val"].as<std::vector<int>>();
-    CHECK(v.size() == 4);
-    CHECK(v[0]==0);
-    CHECK(v[1]==1);
-    CHECK(v[2]==2);
-    CHECK(v[3]==3);
+    CHECK(4 == v.size());
+    CHECK(0 == v[0]);
+    CHECK(1 == v[1]);
+    CHECK(2 == v[2]);
+    CHECK(3 == v[3]);
 }
 
 TEST_CASE("test json_array erase with iterator")
@@ -485,7 +485,7 @@ TEST_CASE("test json_array erase with iterator")
             }
         }
 
-        CHECK(doc.size() == 1);
+        CHECK(1 == doc.size());
         CHECK(doc[0] == "b");
     }
 
@@ -510,7 +510,7 @@ TEST_CASE("test json_array erase with iterator")
             }
         }
 
-        CHECK(doc.size() == 1);
+        CHECK(1 == doc.size());
         CHECK(doc[0] == "c");
     }
 }
